@@ -469,7 +469,7 @@ static agent_info_t *_make_agent_info(agent_arg_t *agent_arg_ptr)
 	agent_info_ptr->msg_args_pptr  = &agent_arg_ptr->msg_args;
 	agent_info_ptr->msg_flags = agent_arg_ptr->msg_flags;
 	agent_info_ptr->protocol_version = agent_arg_ptr->protocol_version;
-	agent_info_ptr->tls_cert = xstrdup(agent_arg_ptr->tls_cert);
+	agent_info_ptr->tls_cert = agent_arg_ptr->tls_cert;
 
 	if (!agent_info_ptr->thread_count)
 		return agent_info_ptr;
@@ -568,7 +568,7 @@ static task_info_t *_make_task_data(agent_info_t *agent_info_ptr, int inx)
 	task_info_ptr->msg_args_ptr      = *agent_info_ptr->msg_args_pptr;
 	task_info_ptr->msg_flags = agent_info_ptr->msg_flags;
 	task_info_ptr->protocol_version  = agent_info_ptr->protocol_version;
-	task_info_ptr->tls_cert = xstrdup(agent_info_ptr->tls_cert);
+	task_info_ptr->tls_cert = agent_info_ptr->tls_cert;
 
 	return task_info_ptr;
 }
@@ -1574,6 +1574,19 @@ extern void agent_fini(void)
 	struct timespec ts = {0, 0};
 	int rc = 0;
 
+	/*
+	 * Wait until we know that slurmctld_config.shutdown_time set. This way,
+	 * each helper thread that is checking slurmctld_config.shutdown_time to
+	 * know when to shutdown can immediately end its slurm_cond_timedwait()
+	 * loop rather than waiting for the next loop.
+	 */
+	slurm_mutex_lock(&slurmctld_config.shutdown_lock);
+	while (!slurmctld_config.shutdown_time) {
+		slurm_cond_wait(&slurmctld_config.shutdown_cond,
+				&slurmctld_config.shutdown_lock);
+	}
+	slurm_mutex_unlock(&slurmctld_config.shutdown_lock);
+
 	agent_trigger(999, true, true);
 
 	slurm_mutex_lock(&update_nodes_mutex);
